@@ -4,8 +4,7 @@ class LinearModel:
   def __init__(self, feature_count, learning_rate, mean =0, std=0.003):
     self.weight = np.random.normal(mean, std, [feature_count, 1])
     self.bias = np.zeros([1])
-    self.learning_rate_ = 0.003
-    # self.learning_rate_ = learning_rate
+    self.learning_rate_ = learning_rate
   
 
   def forward(self, X):
