@@ -15,7 +15,7 @@ class SingleLayerPerceptron:
     if str(type(y)) == "<class 'pandas.core.series.Series'>": y = y.to_numpy().reshape(-1,1)
 
     steps = int(X.shape[0]//self.mini_batch_) # 미니배치가 가능한 갯수
-    self.model = self.MODEL_(int(X.shape[1]), self.learning_rate_)
+    self.model = self.MODEL_(feature_count = int(X.shape[1]), learning_rate = self.learning_rate_)
     # self.model = LinearModel(int(X.shape[1]), self.learning_rate_)
 
     for epoch in range(self.epochs_):
